@@ -57,20 +57,6 @@ typedef struct {
   guint new_keycode;
 } CcUniquenessData;
 
-typedef enum
-{
-  SHORTCUT_TYPE_KEY_ENTRY,
-  SHORTCUT_TYPE_XKB_OPTION,
-} ShortcutType;
-
-enum
-{
-  DETAIL_DESCRIPTION_COLUMN,
-  DETAIL_KEYENTRY_COLUMN,
-  DETAIL_TYPE_COLUMN,
-  DETAIL_N_COLUMNS
-};
-
 enum
 {
   SECTION_DESCRIPTION_COLUMN,
@@ -81,10 +67,6 @@ enum
 
 gchar*   find_free_settings_path        (GSettings *settings);
 
-void     fill_xkb_options_shortcuts     (GtkTreeModel *model);
-
-void     setup_keyboard_options         (GtkListStore *store);
-
 gboolean is_valid_binding               (CcKeyCombo *combo);
 
 gboolean is_empty_binding               (CcKeyCombo *combo);
