@@ -17,8 +17,7 @@
  *
  */
 
-#ifndef CC_WIFI_PANEL_H
-#define CC_WIFI_PANEL_H
+#pragma once
 
 #include <shell/cc-panel.h>
 
@@ -31,6 +30,3 @@ G_DECLARE_FINAL_TYPE (CcWifiPanel, cc_wifi_panel, CC, WIFI_PANEL, CcPanel)
 void                 cc_wifi_panel_static_init_func              (void);
 
 G_END_DECLS
-
-#endif /* CC_WIFI_PANEL_H */
-
