@@ -94,21 +94,18 @@ struct _CcPrintersPanel
   PPDList      *all_ppds_list;
 
   gchar    *new_printer_name;
-  gchar    *new_printer_location;
-  gchar    *new_printer_make_and_model;
-  gboolean  new_printer_on_network;
 
   gchar    *renamed_printer_name;
   gchar    *old_printer_name;
   gchar    *deleted_printer_name;
+  GList    *deleted_printers;
+  GObject  *reference;
 
   GHashTable *printer_entries;
   gboolean    entries_filled;
   GVariant   *action;
 
   GtkSizeGroup *size_group;
-
-  gpointer dummy;
 };
 
 CC_PANEL_REGISTER (CcPrintersPanel, cc_printers_panel)
@@ -136,19 +133,21 @@ execute_action (CcPrintersPanel *self,
   PpPrinterEntry         *printer_entry;
   const gchar            *action_name;
   const gchar            *printer_name;
-  GVariant               *variant;
-  GVariant               *action_variant;
   gint                    count;
 
   count = g_variant_n_children (action);
   if (count == 2)
     {
+      g_autoptr(GVariant) action_variant = NULL;
+
       g_variant_get_child (action, 0, "v", &action_variant);
       action_name = g_variant_get_string (action_variant, NULL);
 
       /* authenticate-jobs printer-name */
       if (g_strcmp0 (action_name, "authenticate-jobs") == 0)
         {
+          g_autoptr(GVariant) variant = NULL;
+
           g_variant_get_child (action, 1, "v", &variant);
           printer_name = g_variant_get_string (variant, NULL);
 
@@ -157,12 +156,12 @@ execute_action (CcPrintersPanel *self,
             pp_printer_entry_authenticate_jobs (printer_entry);
           else
             g_warning ("Could not find printer \"%s\"!", printer_name);
-
-          g_variant_unref (variant);
         }
       /* show-jobs printer-name */
       else if (g_strcmp0 (action_name, "show-jobs") == 0)
         {
+          g_autoptr(GVariant) variant = NULL;
+
           g_variant_get_child (action, 1, "v", &variant);
           printer_name = g_variant_get_string (variant, NULL);
 
@@ -171,11 +170,7 @@ execute_action (CcPrintersPanel *self,
             pp_printer_entry_show_jobs_dialog (printer_entry);
           else
             g_warning ("Could not find printer \"%s\"!", printer_name);
-
-          g_variant_unref (variant);
         }
-
-      g_variant_unref (action_variant);
     }
 }
 
@@ -254,11 +249,37 @@ printer_removed_cb (GObject      *source_object,
                     GAsyncResult *result,
                     gpointer      user_data)
 {
+  PpPrinter *printer = PP_PRINTER (source_object);
   g_autoptr(GError) error = NULL;
+  g_autofree gchar *printer_name = NULL;
 
-  pp_printer_delete_finish (PP_PRINTER (source_object), result, &error);
+  g_object_get (printer, "printer-name", &printer_name, NULL);
+  pp_printer_delete_finish (printer, result, &error);
   g_object_unref (source_object);
 
+  if (user_data != NULL)
+    {
+      GObject *reference = G_OBJECT (user_data);
+
+      if (g_object_get_data (reference, "self") != NULL)
+        {
+          CcPrintersPanel *self = CC_PRINTERS_PANEL (g_object_get_data (reference, "self"));
+          GList           *iter;
+
+          for (iter = self->deleted_printers; iter != NULL; iter = iter->next)
+            {
+              if (g_strcmp0 (iter->data, printer_name) == 0)
+                {
+                  g_free (iter->data);
+                  self->deleted_printers = g_list_delete_link (self->deleted_printers, iter);
+                  break;
+                }
+            }
+        }
+
+      g_object_unref (reference);
+    }
+
   if (error != NULL)
     g_warning ("Printer could not be deleted: %s", error->message);
 }
@@ -281,8 +302,6 @@ cc_printers_panel_dispose (GObject *object)
 
   g_clear_object (&self->pp_new_printer_dialog);
   g_clear_pointer (&self->new_printer_name, g_free);
-  g_clear_pointer (&self->new_printer_location, g_free);
-  g_clear_pointer (&self->new_printer_make_and_model, g_free);
   g_clear_pointer (&self->renamed_printer_name, g_free);
   g_clear_pointer (&self->old_printer_name, g_free);
   g_clear_object (&self->builder);
@@ -295,16 +314,15 @@ cc_printers_panel_dispose (GObject *object)
   g_clear_pointer (&self->printer_entries, g_hash_table_destroy);
   g_clear_pointer (&self->all_ppds_list, ppd_list_free);
   free_dests (self);
+  g_list_free_full (self->deleted_printers, g_free);
+  self->deleted_printers = NULL;
+  if (self->reference != NULL)
+    g_object_set_data (self->reference, "self", NULL);
+  g_clear_object (&self->reference);
 
   G_OBJECT_CLASS (cc_printers_panel_parent_class)->dispose (object);
 }
 
-static void
-cc_printers_panel_finalize (GObject *object)
-{
-  G_OBJECT_CLASS (cc_printers_panel_parent_class)->finalize (object);
-}
-
 static const char *
 cc_printers_panel_get_help_uri (CcPanel *panel)
 {
@@ -321,7 +339,6 @@ cc_printers_panel_class_init (CcPrintersPanelClass *klass)
   object_class->set_property = cc_printers_panel_set_property;
   object_class->constructed = cc_printers_panel_constructed;
   object_class->dispose = cc_printers_panel_dispose;
-  object_class->finalize = cc_printers_panel_finalize;
 
   panel_class->get_help_uri = cc_printers_panel_get_help_uri;
 
@@ -336,9 +353,7 @@ on_get_job_attributes_cb (GObject      *source_object,
   CcPrintersPanel        *self = (CcPrintersPanel*) user_data;
   const gchar            *job_originating_user_name;
   const gchar            *job_printer_uri;
-  GVariant               *attributes;
-  GVariant               *username;
-  GVariant               *printer_uri;
+  g_autoptr(GVariant)     attributes = NULL;
   g_autoptr(GError)       error = NULL;
 
   attributes = pp_job_get_attributes_finish (PP_JOB (source_object), res, &error);
@@ -346,8 +361,12 @@ on_get_job_attributes_cb (GObject      *source_object,
 
   if (attributes != NULL)
     {
+      g_autoptr(GVariant) username = NULL;
+
       if ((username = g_variant_lookup_value (attributes, "job-originating-user-name", G_VARIANT_TYPE ("as"))) != NULL)
         {
+          g_autoptr(GVariant) printer_uri = NULL;
+
           if ((printer_uri = g_variant_lookup_value (attributes, "job-printer-uri", G_VARIANT_TYPE ("as"))) != NULL)
             {
               job_originating_user_name = g_variant_get_string (g_variant_get_child_value (username, 0), NULL);
@@ -366,14 +385,8 @@ on_get_job_attributes_cb (GObject      *source_object,
 
                   pp_printer_entry_update_jobs_count (printer_entry);
                 }
-
-              g_variant_unref (printer_uri);
             }
-
-          g_variant_unref (username);
         }
-
-      g_variant_unref (attributes);
     }
 }
 
@@ -620,72 +633,71 @@ free_dests (CcPrintersPanel *self)
 }
 
 static void
-cancel_notification_timeout (CcPrintersPanel *self)
+on_printer_deletion_undone (CcPrintersPanel *self)
 {
-  if (self->remove_printer_timeout_id == 0)
-    return;
-
-  g_source_remove (self->remove_printer_timeout_id);
-
-  self->remove_printer_timeout_id = 0;
-}
-
-static void
-on_printer_deletion_undone (GtkButton *button,
-                            gpointer   user_data)
-{
-  CcPrintersPanel        *self = (CcPrintersPanel*) user_data;
+  GtkWidget *widget;
 
   gtk_revealer_set_reveal_child (self->notification, FALSE);
 
   g_clear_pointer (&self->deleted_printer_name, g_free);
-  actualize_printers_list (self);
 
-  cancel_notification_timeout (self);
+  widget = (GtkWidget*) gtk_builder_get_object (self->builder, "content");
+  gtk_list_box_invalidate_filter (GTK_LIST_BOX (widget));
+
+  g_clear_handle_id (&self->remove_printer_timeout_id, g_source_remove);
 }
 
 static void
-on_notification_dismissed (GtkButton *button,
-                           gpointer   user_data)
+on_notification_dismissed (CcPrintersPanel *self)
 {
-  CcPrintersPanel        *self = (CcPrintersPanel*) user_data;
+  g_clear_handle_id (&self->remove_printer_timeout_id, g_source_remove);
 
   if (self->deleted_printer_name != NULL)
     {
       PpPrinter *printer;
 
       printer = pp_printer_new (self->deleted_printer_name);
+      /* The reference tells to the callback whether
+         printers panel was already destroyed so
+         it knows whether it can access the list
+         of deleted printers in it (see below).
+       */
       pp_printer_delete_async (printer,
                                NULL,
                                printer_removed_cb,
-                               NULL);
+                               g_object_ref (self->reference));
 
-      g_clear_pointer (&self->deleted_printer_name, g_free);
+      /* List of printers which were recently deleted but are still available
+         in CUPS due to async nature of the method (e.g. quick deletion
+         of several printers).
+       */
+      self->deleted_printers = g_list_prepend (self->deleted_printers, self->deleted_printer_name);
+      self->deleted_printer_name = NULL;
     }
 
   gtk_revealer_set_reveal_child (self->notification, FALSE);
 }
 
 static gboolean
-on_remove_printer_timeout (gpointer user_data)
+on_remove_printer_timeout (CcPrintersPanel *self)
 {
-  on_notification_dismissed (NULL, user_data);
+  self->remove_printer_timeout_id = 0;
+
+  on_notification_dismissed (self);
 
   return G_SOURCE_REMOVE;
 }
 
 static void
-on_printer_deleted (PpPrinterEntry *printer_entry,
-                    gpointer        user_data)
+on_printer_deleted (CcPrintersPanel *self,
+                    PpPrinterEntry  *printer_entry)
 {
-  CcPrintersPanel        *self = (CcPrintersPanel*) user_data;
-  GtkLabel               *label;
-  g_autofree gchar       *notification_message = NULL;
-  g_autofree gchar       *printer_name = NULL;
+  GtkLabel         *label;
+  g_autofree gchar *notification_message = NULL;
+  g_autofree gchar *printer_name = NULL;
+  GtkWidget        *widget;
 
-  gtk_widget_hide (GTK_WIDGET (printer_entry));
-
-  on_notification_dismissed (NULL, self);
+  on_notification_dismissed (self);
 
   g_object_get (printer_entry,
                 "printer-name", &printer_name,
@@ -700,18 +712,19 @@ on_printer_deleted (PpPrinterEntry *printer_entry,
 
   self->deleted_printer_name = g_strdup (printer_name);
 
+  widget = (GtkWidget*) gtk_builder_get_object (self->builder, "content");
+  gtk_list_box_invalidate_filter (GTK_LIST_BOX (widget));
+
   gtk_revealer_set_reveal_child (self->notification, TRUE);
 
-  self->remove_printer_timeout_id = g_timeout_add_seconds (10, on_remove_printer_timeout, self);
+  self->remove_printer_timeout_id = g_timeout_add_seconds (10, G_SOURCE_FUNC (on_remove_printer_timeout), self);
 }
 
 static void
-on_printer_renamed (PpPrinterEntry *printer_entry,
-                    gchar          *new_name,
-                    gpointer        user_data)
+on_printer_renamed (CcPrintersPanel *self,
+                    gchar           *new_name,
+                    PpPrinterEntry  *printer_entry)
 {
-  CcPrintersPanel        *self = (CcPrintersPanel*) user_data;
-
   g_object_get (printer_entry,
                 "printer-name",
                 &self->old_printer_name,
@@ -720,10 +733,9 @@ on_printer_renamed (PpPrinterEntry *printer_entry,
 }
 
 static void
-on_printer_changed (PpPrinterEntry *printer_entry,
-                    gpointer        user_data)
+on_printer_changed (CcPrintersPanel *self)
 {
-  actualize_printers_list (user_data);
+  actualize_printers_list (self);
 }
 
 static void
@@ -743,18 +755,21 @@ add_printer_entry (CcPrintersPanel *self,
     gtk_size_group_add_widget (self->size_group, GTK_WIDGET (l->data));
   g_slist_free (widgets);
 
-  g_signal_connect (printer_entry,
-                    "printer-changed",
-                    G_CALLBACK (on_printer_changed),
-                    self);
-  g_signal_connect (printer_entry,
-                    "printer-delete",
-                    G_CALLBACK (on_printer_deleted),
-                    self);
-  g_signal_connect (printer_entry,
-                    "printer-renamed",
-                    G_CALLBACK (on_printer_renamed),
-                    self);
+  g_signal_connect_object (printer_entry,
+                           "printer-changed",
+                           G_CALLBACK (on_printer_changed),
+                           self,
+                           G_CONNECT_SWAPPED);
+  g_signal_connect_object (printer_entry,
+                           "printer-delete",
+                           G_CALLBACK (on_printer_deleted),
+                           self,
+                           G_CONNECT_SWAPPED);
+  g_signal_connect_object (printer_entry,
+                           "printer-renamed",
+                           G_CALLBACK (on_printer_renamed),
+                           self,
+                           G_CONNECT_SWAPPED);
 
   gtk_list_box_insert (GTK_LIST_BOX (content), GTK_WIDGET (printer_entry), -1);
   gtk_widget_show_all (content);
@@ -784,6 +799,33 @@ set_current_page (GObject      *source_object,
   update_sensitivity (user_data);
 }
 
+static void
+destroy_nonexisting_entries (PpPrinterEntry *entry,
+                             gpointer        user_data)
+{
+  CcPrintersPanel  *self = (CcPrintersPanel *) user_data;
+  g_autofree gchar *printer_name = NULL;
+  gboolean          exists = FALSE;
+  gint              i;
+
+  g_object_get (G_OBJECT (entry), "printer-name", &printer_name, NULL);
+
+  for (i = 0; i < self->num_dests; i++)
+    {
+      if (g_strcmp0 (self->dests[i].name, printer_name) == 0)
+        {
+          exists = TRUE;
+          break;
+        }
+    }
+
+  if (!exists)
+    {
+      gtk_widget_destroy (GTK_WIDGET (entry));
+      g_hash_table_remove (self->printer_entries, printer_name);
+    }
+}
+
 static void
 actualize_printers_list_cb (GObject      *source_object,
                             GAsyncResult *result,
@@ -795,6 +837,7 @@ actualize_printers_list_cb (GObject      *source_object,
   PpCupsDests            *cups_dests;
   gboolean                new_printer_available = FALSE;
   g_autoptr(GError)       error = NULL;
+  gpointer                item;
   int                     i;
 
   cups_dests = pp_cups_get_dests_finish (cups, result, &error);
@@ -822,7 +865,7 @@ actualize_printers_list_cb (GObject      *source_object,
     gtk_stack_set_visible_child_name (GTK_STACK (widget), "printers-list");
 
   widget = (GtkWidget*) gtk_builder_get_object (self->builder, "content");
-  gtk_container_foreach (GTK_CONTAINER (widget), (GtkCallback) gtk_widget_destroy, NULL);
+  gtk_container_foreach (GTK_CONTAINER (widget), (GtkCallback) destroy_nonexisting_entries, self);
 
   for (i = 0; i < self->num_dests; i++)
     {
@@ -833,13 +876,14 @@ actualize_printers_list_cb (GObject      *source_object,
 
   for (i = 0; i < self->num_dests; i++)
     {
-      if (g_strcmp0 (self->dests[i].name, self->deleted_printer_name) == 0)
-          continue;
-
       if (new_printer_available && g_strcmp0 (self->dests[i].name, self->old_printer_name) == 0)
           continue;
 
-      add_printer_entry (self, self->dests[i]);
+      item = g_hash_table_lookup (self->printer_entries, self->dests[i].name);
+      if (item != NULL)
+        pp_printer_entry_update (PP_PRINTER_ENTRY (item), self->dests[i], self->is_authorized);
+      else
+        add_printer_entry (self, self->dests[i]);
     }
 
   if (!self->entries_filled)
@@ -857,6 +901,30 @@ actualize_printers_list_cb (GObject      *source_object,
   update_sensitivity (user_data);
 
   g_object_unref (cups);
+
+  if (self->new_printer_name != NULL)
+    {
+      GtkScrolledWindow      *scrolled_window;
+      GtkAllocation           allocation;
+      GtkAdjustment          *adjustment;
+      GtkWidget              *printer_entry;
+
+      /* Scroll the view to show the newly added printer-entry. */
+      scrolled_window = GTK_SCROLLED_WINDOW (gtk_builder_get_object (self->builder,
+                                                                     "scrolled-window"));
+      adjustment = gtk_scrolled_window_get_vadjustment (scrolled_window);
+
+      printer_entry = GTK_WIDGET (g_hash_table_lookup (self->printer_entries,
+                                                       self->new_printer_name));
+      if (printer_entry != NULL)
+        {
+          gtk_widget_get_allocation (printer_entry, &allocation);
+          g_clear_pointer (&self->new_printer_name, g_free);
+
+          gtk_adjustment_set_value (adjustment,
+                                    allocation.y - gtk_widget_get_margin_top (printer_entry));
+        }
+    }
 }
 
 static void
@@ -872,40 +940,24 @@ actualize_printers_list (CcPrintersPanel *self)
 }
 
 static void
-new_printer_dialog_pre_response_cb (PpNewPrinterDialog *dialog,
-                                    const gchar        *device_name,
-                                    const gchar        *device_location,
-                                    const gchar        *device_make_and_model,
-                                    gboolean            is_network_device,
-                                    gpointer            user_data)
+new_printer_dialog_pre_response_cb (CcPrintersPanel *self,
+                                    const gchar     *device_name,
+                                    const gchar     *device_location,
+                                    const gchar     *device_make_and_model,
+                                    gboolean         is_network_device)
 {
-  CcPrintersPanel        *self = (CcPrintersPanel*) user_data;
-
   self->new_printer_name = g_strdup (device_name);
-  self->new_printer_location = g_strdup (device_location);
-  self->new_printer_make_and_model = g_strdup (device_make_and_model);
-  self->new_printer_on_network = is_network_device;
 
   actualize_printers_list (self);
 }
 
 static void
-new_printer_dialog_response_cb (PpNewPrinterDialog *dialog,
-                                gint                response_id,
-                                gpointer            user_data)
+new_printer_dialog_response_cb (CcPrintersPanel *self,
+                                gint             response_id)
 {
-  CcPrintersPanel        *self = (CcPrintersPanel*) user_data;
-  GtkScrolledWindow      *scrolled_window;
-  GtkAllocation           allocation;
-  GtkAdjustment          *adjustment;
-  GtkWidget              *printer_entry;
-
   if (self->pp_new_printer_dialog)
     g_clear_object (&self->pp_new_printer_dialog);
 
-  g_clear_pointer (&self->new_printer_location, g_free);
-  g_clear_pointer (&self->new_printer_make_and_model, g_free);
-
   if (response_id == GTK_RESPONSE_REJECT)
     {
       GtkWidget *message_dialog;
@@ -924,45 +976,29 @@ new_printer_dialog_response_cb (PpNewPrinterDialog *dialog,
     }
 
   actualize_printers_list (self);
-
-  if (self->new_printer_name == NULL)
-    return;
-
-  /* Scroll the view to show the newly added printer-entry. */
-  scrolled_window = GTK_SCROLLED_WINDOW (gtk_builder_get_object (self->builder,
-                                                                 "scrolled-window"));
-  adjustment = gtk_scrolled_window_get_vadjustment (scrolled_window);
-
-  printer_entry = GTK_WIDGET (g_hash_table_lookup (self->printer_entries,
-                                                   self->new_printer_name));
-  gtk_widget_get_allocation (printer_entry, &allocation);
-  g_clear_pointer (&self->new_printer_name, g_free);
-
-  gtk_adjustment_set_value (adjustment,
-                            allocation.y - gtk_widget_get_margin_top (printer_entry));
 }
 
 static void
-printer_add_cb (GtkToolButton *toolbutton,
-                gpointer       user_data)
+printer_add_cb (CcPrintersPanel *self)
 {
-  CcPrintersPanel        *self = (CcPrintersPanel*) user_data;
-  GtkWidget              *toplevel;
+  GtkWidget *toplevel;
 
   toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
   self->pp_new_printer_dialog = PP_NEW_PRINTER_DIALOG (
     pp_new_printer_dialog_new (GTK_WINDOW (toplevel),
                                self->all_ppds_list));
 
-  g_signal_connect (self->pp_new_printer_dialog,
-                    "pre-response",
-                    G_CALLBACK (new_printer_dialog_pre_response_cb),
-                    self);
+  g_signal_connect_object (self->pp_new_printer_dialog,
+                           "pre-response",
+                           G_CALLBACK (new_printer_dialog_pre_response_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
 
-  g_signal_connect (self->pp_new_printer_dialog,
-                    "response",
-                    G_CALLBACK (new_printer_dialog_response_cb),
-                    self);
+  g_signal_connect_object (self->pp_new_printer_dialog,
+                           "response",
+                           G_CALLBACK (new_printer_dialog_response_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
 }
 
 static void
@@ -1006,21 +1042,16 @@ update_sensitivity (gpointer user_data)
 }
 
 static void
-on_permission_changed (GPermission *permission,
-                       GParamSpec  *pspec,
-                       gpointer     data)
+on_permission_changed (CcPrintersPanel *self)
 {
-  actualize_printers_list (data);
-  update_sensitivity (data);
+  actualize_printers_list (self);
+  update_sensitivity (self);
 }
 
 static void
-on_lockdown_settings_changed (GSettings  *settings,
-                              const char *key,
-                              gpointer    user_data)
+on_lockdown_settings_changed (CcPrintersPanel *self,
+                              const char      *key)
 {
-  CcPrintersPanel         *self = (CcPrintersPanel*) user_data;
-
   if (g_str_equal (key, "disable-print-setup") == FALSE)
     return;
 
@@ -1030,7 +1061,7 @@ on_lockdown_settings_changed (GSettings  *settings,
     !g_settings_get_boolean (self->lockdown_settings, "disable-print-setup"));
 #endif
 
-  on_permission_changed (self->permission, NULL, user_data);
+  on_permission_changed (self);
 }
 
 static void
@@ -1128,30 +1159,85 @@ filter_function (GtkListBoxRow *row,
   g_autofree gchar       *location = NULL;
   g_autofree gchar       *printer_name = NULL;
   g_autofree gchar       *printer_location = NULL;
-
-  search_entry = (GtkWidget*)
-    gtk_builder_get_object (self->builder, "search-entry");
-
-  if (gtk_entry_get_text_length (GTK_ENTRY (search_entry)) == 0)
-    return TRUE;
+  GList                  *iter;
 
   g_object_get (G_OBJECT (row),
                 "printer-name", &printer_name,
                 "printer-location", &printer_location,
                 NULL);
 
-  name = cc_util_normalize_casefold_and_unaccent (printer_name);
-  location = cc_util_normalize_casefold_and_unaccent (printer_location);
+  search_entry = (GtkWidget*)
+    gtk_builder_get_object (self->builder, "search-entry");
 
-  search = cc_util_normalize_casefold_and_unaccent (gtk_entry_get_text (GTK_ENTRY (search_entry)));
+  if (gtk_entry_get_text_length (GTK_ENTRY (search_entry)) == 0)
+    {
+      retval = TRUE;
+    }
+  else
+    {
+      name = cc_util_normalize_casefold_and_unaccent (printer_name);
+      location = cc_util_normalize_casefold_and_unaccent (printer_location);
 
-  retval = strstr (name, search) != NULL;
-  if (location != NULL)
-      retval = retval || (strstr (location, search) != NULL);
+      search = cc_util_normalize_casefold_and_unaccent (gtk_entry_get_text (GTK_ENTRY (search_entry)));
+
+      retval = strstr (name, search) != NULL;
+      if (location != NULL)
+          retval = retval || (strstr (location, search) != NULL);
+    }
+
+  if (self->deleted_printer_name != NULL &&
+      g_strcmp0 (self->deleted_printer_name, printer_name) == 0)
+    {
+      retval = FALSE;
+    }
+
+  if (self->deleted_printers != NULL)
+    {
+      for (iter = self->deleted_printers; iter != NULL; iter = iter->next)
+        {
+          if (g_strcmp0 (iter->data, printer_name) == 0)
+            {
+              retval = FALSE;
+              break;
+            }
+        }
+    }
 
   return retval;
 }
 
+static gint
+sort_function (GtkListBoxRow *row1,
+               GtkListBoxRow *row2,
+               gpointer       user_data)
+{
+  g_autofree gchar *printer_name1 = NULL;
+  g_autofree gchar *printer_name2 = NULL;
+
+  g_object_get (G_OBJECT (row1),
+                "printer-name", &printer_name1,
+                NULL);
+
+  g_object_get (G_OBJECT (row2),
+                "printer-name", &printer_name2,
+                NULL);
+
+  if (printer_name1 != NULL)
+    {
+      if (printer_name2 != NULL)
+        return g_ascii_strcasecmp (printer_name1, printer_name2);
+      else
+        return 1;
+    }
+  else
+    {
+      if (printer_name2 != NULL)
+        return -1;
+      else
+        return 0;
+    }
+}
+
 static void
 cc_printers_panel_init (CcPrintersPanel *self)
 {
@@ -1166,42 +1252,17 @@ cc_printers_panel_init (CcPrintersPanel *self)
 
   /* initialize main data structure */
   self->builder = gtk_builder_new ();
-  self->dests = NULL;
-  self->num_dests = 0;
-
-  self->pp_new_printer_dialog = NULL;
-
-  self->subscription_id = 0;
-  self->cups_status_check_id = 0;
-  self->subscription_renewal_id = 0;
-  self->cups_proxy = NULL;
-  self->cups_bus_connection = NULL;
-  self->dbus_subscription_id = 0;
-  self->remove_printer_timeout_id = 0;
-
-  self->new_printer_name = NULL;
-  self->new_printer_location = NULL;
-  self->new_printer_make_and_model = NULL;
-  self->new_printer_on_network = FALSE;
-
-  self->renamed_printer_name = NULL;
-  self->old_printer_name = NULL;
-  self->deleted_printer_name = NULL;
-
-  self->permission = NULL;
-  self->lockdown_settings = NULL;
-
-  self->all_ppds_list = NULL;
+  self->reference = g_object_new (G_TYPE_OBJECT, NULL);
 
   self->printer_entries = g_hash_table_new_full (g_str_hash,
                                                  g_str_equal,
                                                  g_free,
                                                  NULL);
-  self->entries_filled = FALSE;
-  self->action = NULL;
 
   g_type_ensure (CC_TYPE_PERMISSION_INFOBAR);
 
+  g_object_set_data_full (self->reference, "self", self, NULL);
+
   builder_result = gtk_builder_add_objects_from_resource (self->builder,
                                                           "/org/gnome/control-center/printers/printers.ui",
                                                           objects, &error);
@@ -1218,11 +1279,11 @@ cc_printers_panel_init (CcPrintersPanel *self)
 
   widget = (GtkWidget*)
     gtk_builder_get_object (self->builder, "notification-undo-button");
-  g_signal_connect (widget, "clicked", G_CALLBACK (on_printer_deletion_undone), self);
+  g_signal_connect_object (widget, "clicked", G_CALLBACK (on_printer_deletion_undone), self, G_CONNECT_SWAPPED);
 
   widget = (GtkWidget*)
     gtk_builder_get_object (self->builder, "notification-dismiss-button");
-  g_signal_connect (widget, "clicked", G_CALLBACK (on_notification_dismissed), self);
+  g_signal_connect_object (widget, "clicked", G_CALLBACK (on_notification_dismissed), self, G_CONNECT_SWAPPED);
 
   self->permission_infobar = (CcPermissionInfobar*)
     gtk_builder_get_object (self->builder, "permission-infobar");
@@ -1234,11 +1295,11 @@ cc_printers_panel_init (CcPrintersPanel *self)
   /* connect signals */
   widget = (GtkWidget*)
     gtk_builder_get_object (self->builder, "printer-add-button");
-  g_signal_connect (widget, "clicked", G_CALLBACK (printer_add_cb), self);
+  g_signal_connect_object (widget, "clicked", G_CALLBACK (printer_add_cb), self, G_CONNECT_SWAPPED);
 
   widget = (GtkWidget*)
     gtk_builder_get_object (self->builder, "printer-add-button2");
-  g_signal_connect (widget, "clicked", G_CALLBACK (printer_add_cb), self);
+  g_signal_connect_object (widget, "clicked", G_CALLBACK (printer_add_cb), self, G_CONNECT_SWAPPED);
 
   widget = (GtkWidget*)
     gtk_builder_get_object (self->builder, "content");
@@ -1250,6 +1311,10 @@ cc_printers_panel_init (CcPrintersPanel *self)
                             "search-changed",
                             G_CALLBACK (gtk_list_box_invalidate_filter),
                             widget);
+  gtk_list_box_set_sort_func (GTK_LIST_BOX (widget),
+                              sort_function,
+                              NULL,
+                              NULL);
 
   self->lockdown_settings = g_settings_new ("org.gnome.desktop.lockdown");
   if (self->lockdown_settings)
@@ -1257,7 +1322,7 @@ cc_printers_panel_init (CcPrintersPanel *self)
                              "changed",
                              G_CALLBACK (on_lockdown_settings_changed),
                              self,
-                             G_CONNECT_AFTER);
+                             G_CONNECT_SWAPPED | G_CONNECT_AFTER);
 
   /* Add unlock button */
   self->permission = (GPermission *)polkit_permission_new_sync (
@@ -1268,12 +1333,12 @@ cc_printers_panel_init (CcPrintersPanel *self)
                                "notify",
                                G_CALLBACK (on_permission_changed),
                                self,
-                               G_CONNECT_AFTER);
+                               G_CONNECT_SWAPPED | G_CONNECT_AFTER);
 
       cc_permission_infobar_set_permission (self->permission_infobar,
                                             self->permission);
 
-      on_permission_changed (self->permission, NULL, self);
+      on_permission_changed (self);
     }
   else
     g_warning ("Your system does not have the cups-pk-helper's policy \
