@@ -35,3 +35,7 @@ GSList         *pp_printer_entry_get_size_group_widgets (PpPrinterEntry *self);
 void            pp_printer_entry_show_jobs_dialog (PpPrinterEntry *self);
 
 void            pp_printer_entry_authenticate_jobs (PpPrinterEntry *self);
+
+void            pp_printer_entry_update (PpPrinterEntry *self,
+                                         cups_dest_t     printer,
+                                         gboolean        is_authorized);
