@@ -583,7 +583,7 @@ print_file_thread (GTask        *task,
   if (response != NULL)
     {
       if (ippGetState (response) == IPP_ERROR)
-        g_warning ("An error has occured during printing of test page.");
+        g_warning ("An error has occurred during printing of test page.");
       if (ippGetState (response) == IPP_STATE_IDLE)
         ret = TRUE;
 
