@@ -20,14 +20,10 @@
 
 #pragma once
 
-#define HANDY_USE_UNSTABLE_API
-#include <handy.h>
-#undef HANDY_USE_UNSTABLE_API
-
 #include "cc-search-panel.h"
 
 #define CC_SEARCH_LOCATIONS_DIALOG_TYPE (cc_search_locations_dialog_get_type ())
-G_DECLARE_FINAL_TYPE (CcSearchLocationsDialog, cc_search_locations_dialog, CC, SEARCH_LOCATIONS_DIALOG, HdyDialog)
+G_DECLARE_FINAL_TYPE (CcSearchLocationsDialog, cc_search_locations_dialog, CC, SEARCH_LOCATIONS_DIALOG, GtkDialog)
 
 CcSearchLocationsDialog *cc_search_locations_dialog_new (CcSearchPanel *panel);
 
